# -*- coding: utf-8 -*-

#     ____  _ __             _
#    / __ )(_) /__________  (_)___  _____
#   / __  / / __/ ___/ __ \/ / __ \/ ___/
#  / /_/ / / /_/ /__/ /_/ / / / / (__  )
# /_____/_/\__/\___/\____/_/_/ /_/____/

"""
bitcoins Cryptocurrency library
~~~~~~~~~~~~~~~~~~~~~

Bitcoins is an cryptocurrency library, written in Python, for human beings.

:copyright: (c) 2012 by Kenan Yildirim.
:license: MIT, see LICENSE for more details.

"""

__title__ = 'bitcoins'
__version__ = '0.0.0'
__build__ = 0x000000
__author__ = 'Kenan Yildirim'
__license__ = 'MIT'
__copyright__ = 'Copyright 2012 Kenan Yildirim'

from .api import get_difficulty